Traversal

Struct Traversal 

pub struct Traversal<'a> {
    pub visitor: &'a mut dyn Visitor,
}
Traverse a GraphQL AST in a Depth-first fashion

Each handler in the traversal calls a *_enter method and a *_exit method. Use *_enter visitor if you want to traverse the AST in a pre-order fashion, and *_exit visitor if you want to traverse the AST in a post-order fashion.

Fields

visitor: &'a mut dyn Visitor

The input visitor that implements the visitor trait with *_enter and *_exit callbacks

Implementations

Source

impl<'a> Traversal<'a>

pub fn handle_document( &mut self, document: &Document, ) -> Result<(), GraphQLError>

Handle GraphQL Document node

pub fn handle_operation_definition( &mut self, operation_definition: &OperationDefinition, ) -> Result<(), GraphQLError>

Handle GraphQL OperationDefinition node

pub fn handle_query(&mut self, query: &Query) -> Result<(), GraphQLError>

Handle GraphQL Query node

pub fn handle_variable_definition( &mut self, variable_definition: &VariableDefinition, ) -> Result<(), GraphQLError>

Handle GraphQL VariableDefinition node

pub fn handle_selection_set( &mut self, selection_set: &SelectionSet, ) -> Result<(), GraphQLError>

Handle GraphQL SelectionSet node

pub fn handle_selection( &mut self, selection: &Selection, ) -> Result<(), GraphQLError>

Handle GraphQL Selection node

pub fn handle_field(&mut self, field: &Field) -> Result<(), GraphQLError>

Handle GraphQL Field node

pub fn handle_fragment_definition( &mut self, fragment_definition: &FragmentDefinition, ) -> Result<(), GraphQLError>

Handle GraphQL FragmentDefinition node

pub fn handle_inline_fragment( &mut self, inline_fragment: &InlineFragment, ) -> Result<(), GraphQLError>

Handle GraphQL InlineFragment node

pub fn handle_fragment_spread( &mut self, fragment_spread: &FragmentSpread, ) -> Result<(), GraphQLError>

Handle GraphQL FragmentSpread node

pub fn handle_directive( &mut self, directive: &Directive, ) -> Result<(), GraphQLError>

Handle GraphQL Directive node

pub fn handle_type_condition( &mut self, type_condition: &TypeCondition, ) -> Result<(), GraphQLError>

Handle GraphQL TypeCondition node

pub fn handle_type(&mut self, type1: &Type) -> Result<(), GraphQLError>

Handle GraphQL Type node

pub fn handle_name(&mut self, name: &Name) -> Result<(), GraphQLError>

Handle GraphQL Name node

pub fn handle_value(&mut self, value: &Value) -> Result<(), GraphQLError>

Handle GraphQL Value node